======
toucai
======




.. image:: https://pyup.io/repos/github/leokster/toucai/shield.svg
     :target: https://pyup.io/repos/github/leokster/toucai/
     :alt: Updates



Python Boilerplate contains all the boilerplate you need to create a Python package.



Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
